//
//  MenuScene.swift
//  GoldWars
//
//  Created by Aldin Duraki on 18.04.20.
//  Copyright © 2020 SP2. All rights reserved.
//

import SpriteKit
import SceneKit
class MenuScene: SKScene {

    var entityManager: EntityManager!

    override func sceneDidLoad() {
        entityManager = EntityManager(scene: self)
        let midX = self.size.width / 2
        let midY = self.size.height / 2
        entityManager.add(Button(name: "startGameButton",
                                 iconName: "",
                                 text: "Start Game",
                                 position: CGPoint(x: midX, y: midY),
                                 onButtonPress: {
                                    if CommandLine.arguments.contains("--no-matchmaking") {
                                        self.loadScene(scene: GameScene(size: self.size))
                                        SoundManager.sharedInstance.stopMenuMusic()
                                    } else {
                                    MatchmakingHelper.sharedInstance.presentMatchmaker(scene: self)
                                    }
                                 }))
        entityManager.add(Button(name: "settingsButton",
                                 iconName: "",
                                 text: "Settings",
                                 position: CGPoint(x: midX, y: midY - 80 ),
                                 onButtonPress: {
                                    self.loadScene(scene: SettingsScene(size: self.size))
        }))
        entityManager.add(Background(size: self.size))

		let scnScene: SCNScene = {
			let scnScene = SCNScene()
			let cylinder = SCNCylinder(radius: 250, height: 50)

			let material = SCNMaterial()
			let material2 = SCNMaterial()
			material.diffuse.contents = UIImage(named: "logo_no_background")
			material2.diffuse.contents = UIImage(named: "logo_kante")

			cylinder.materials = [material2,material,material]


			let cylinderNode = SCNNode(geometry: cylinder)
			cylinderNode.eulerAngles = SCNVector3(x: Float(CGFloat.pi / 2), y: 0, z: Float(CGFloat.pi / 2))



			let action = SCNAction.rotateBy(x: CGFloat(GLKMathDegreesToRadians(360)), y:0 , z: 0, duration: 8)
			let forever = SCNAction.repeatForever(action)
			cylinderNode.runAction(forever)
			scnScene.rootNode.addChildNode(cylinderNode)
			return scnScene
		}()

		let node = SK3DNode(viewportSize: CGSize(width: 250, height: 250))
		node.scnScene = scnScene
		node.position = CGPoint(x: midX, y: midY + 200)

		self.addChild(node)
        
        if SoundManager.sharedInstance.isMusicPlaying == false && SoundManager.sharedInstance.isMusicEnabled == true {
            SoundManager.sharedInstance.startMenuMusic()
        }
    }

    func loadScene(scene: SKScene) {
        let transition = SKTransition.flipVertical(withDuration: 0.5)
        self.view?.presentScene(scene, transition: transition)
    }

    override func update(_ currentTime: TimeInterval) {
        entityManager.getBackground()!.update(deltaTime: currentTime)
        entityManager.getButtonByName(buttonName: "startGameButton").component(ofType: ButtonComponent.self)?.buttonNode.isEnabled = GameCenterHelper.isAuthenticated
    }
}
